==> pollen-votecounting-1.0.1-sources.jar: org/chorem/pollen/votecounting/dto/PollChoiceDTO.java <==
/* *##% Pollen
 * Copyright (C) 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>. ##%*/

package org.chorem.pollen.votecounting.dto;

/**
 * Classe DTO représentant un choix de vote.
 *
 * @version $Id: PollChoiceDTO.java 2615 2009-07-01 13:47:45Z nrannou $
 */
public class PollChoiceDTO {

    private String idChoice;

    private String name;

    private String description;

    public PollChoiceDTO(String idChoice) {
        this.idChoice = idChoice;
        this.name = "";
        this.description = "";
    }

    public PollChoiceDTO(int idChoice) {
        this.idChoice = String.valueOf(idChoice);
        this.name = "";
        this.description = "";
    }

    public String getIdChoice() {
        return idChoice;
    }

    public void setIdChoice(String idChoice) {
        this.idChoice = idChoice;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

}

==> pollen-votecounting-1.2.2-sources.jar: org/chorem/pollen/votecounting/dto/PollChoiceDTO.java <==
/* *##% Pollen
 * Copyright (C) 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>. ##%*/

package org.chorem.pollen.votecounting.dto;

/**
 * Classe DTO représentant un choix de vote.
 *
 * @version $Id: PollChoiceDTO.java 2836 2010-01-11 12:46:59Z schorlet $
 */
public class PollChoiceDTO {
    public static final String HIDDEN_PREFIX = "HIDDEN_";

    private String idChoice;

    private String name;

    private String description;

    public PollChoiceDTO(String idChoice) {
        this.idChoice = idChoice;
        this.name = "";
        this.description = "";
    }

    public PollChoiceDTO(int idChoice) {
        this.idChoice = String.valueOf(idChoice);
        this.name = "";
        this.description = "";
    }

    public String getIdChoice() {
        return idChoice;
    }

    public void setIdChoice(String idChoice) {
        this.idChoice = idChoice;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public boolean isHidden() {
        if (name != null) {
            return name.startsWith(HIDDEN_PREFIX);
        }
        
        return false;
    }
}
